@@ -36,7 +36,6 @@ pyfakefs by simply changing their base class from `:py:class`unittest.TestCase`
 to `:py:class`pyfakefs.fake_filesystem_unittest.TestCase`.
 """
 import _io  # type:ignore[import]
-import builtins
 import doctest
 import functools
 import genericpath
@@ -207,7 +206,7 @@ class TestCaseMixin:
     modules by fake implementations.
 
     Attributes:
-        additional_skip_names: names of modules inside of which no module
+        additional_skip_names: names of modules where no module
             replacement shall be performed, in addition to the names in
             :py:attr:`fake_filesystem_unittest.Patcher.SKIPNAMES`.
             Instead of the module names, the modules themselves may be used.
@@ -220,7 +219,7 @@ class TestCaseMixin:
             fully qualified patched module names. Can be used to add patching
             of modules not provided by `pyfakefs`.
 
-    If you specify some of these attributes here and you have DocTests,
+    If you specify some of these attributes here, and you have DocTests,
     consider also specifying the same arguments to :py:func:`load_doctests`.
 
     Example usage in derived test classes::
@@ -322,6 +321,8 @@ class TestCaseMixin:
         :py:func:`setUpPyfakefs` in the same class will not work correctly.
 
         .. note:: This method is only available from Python 3.8 onwards.
+        .. note:: If using `pytest` as testrunner, you need at least pytest 6.2
+            for this method to work.
         """
         if sys.version_info < (3, 8):
             raise NotImplementedError(
@@ -516,7 +517,7 @@ class Patcher:
     ) -> None:
         """
         Args:
-            additional_skip_names: names of modules inside of which no module
+            additional_skip_names: names of modules where no module
                 replacement shall be performed, in addition to the names in
                 :py:attr:`fake_filesystem_unittest.Patcher.SKIPNAMES`.
                 Instead of the module names, the modules themselves
@@ -560,7 +561,6 @@ class Patcher:
         # save the original open function for use in pytest plugin
         self.original_open = open
         self.patch_open_code = patch_open_code
-        self.fake_open: fake_open.FakeFileOpen
 
         if additional_skip_names is not None:
             skip_names = [
@@ -632,7 +632,6 @@ class Patcher:
     @classmethod
     def clear_fs_cache(cls) -> None:
         """Clear the module cache."""
-        print("Clearing the cache")
         cls.CACHED_MODULES = set()
         cls.FS_MODULES = {}
         cls.FS_FUNCTIONS = {}
@@ -654,8 +653,8 @@ class Patcher:
             "io": fake_io.FakeIoModule,
             "pathlib": fake_pathlib.FakePathlibModule,
         }
-        if IS_PYPY:
-            # in PyPy io.open, the module is referenced as _io
+        if IS_PYPY or sys.version_info >= (3, 12):
+            # in PyPy and later cpython versions, the module is referenced as _io
             self._fake_module_classes["_io"] = fake_io.FakeIoModule
         if sys.platform == "win32":
             self._fake_module_classes["nt"] = fake_path.FakeNtModule
@@ -852,7 +851,6 @@ class Patcher:
 
         self.fs = fake_filesystem.FakeFilesystem(patcher=self, create_temp_dir=True)
         self.fs.patch_open_code = self.patch_open_code
-        self.fake_open = fake_open.FakeFileOpen(self.fs)
         for name in self._fake_module_classes:
             self.fake_modules[name] = self._fake_module_classes[name](self.fs)
             if hasattr(self.fake_modules[name], "skip_names"):
@@ -931,9 +929,6 @@ class Patcher:
             for module, attr in modules:
                 if attr in self.unfaked_modules:
                     self._stubs.smart_set(module, name, self.unfaked_modules[attr])
-        if sys.version_info >= (3, 12):
-            # workaround for patching open - does not work with skip modules
-            self._stubs.smart_set(builtins, "open", self.fake_open)
 
     def patch_defaults(self) -> None:
         for fct, idx, ft in self.FS_DEFARGS:
@@ -1022,7 +1017,7 @@ class Patcher:
 class Pause:
     """Simple context manager that allows to pause/resume patching the
     filesystem. Patching is paused in the context manager, and resumed after
-    going out of it's scope.
+    going out of its scope.
     """
 
     def __init__(self, caller: Union[Patcher, TestCaseMixin, FakeFilesystem]):
