@@ -39,6 +39,7 @@ from pyfakefs.helpers import (
     make_string_path,
     to_string,
     matching_string,
+    to_bytes,
 )
 
 if TYPE_CHECKING:
@@ -220,7 +221,9 @@ class FakePathModule:
             file_obj = self.filesystem.resolve(path)
             return file_obj.st_mtime
         except OSError:
-            self.filesystem.raise_os_error(errno.ENOENT, winerror=3)
+            self.filesystem.raise_os_error(
+                errno.ENOENT, winerror=3
+            )  # pytype: disable=bad-return-type
 
     def getatime(self, path: AnyStr) -> float:
         """Returns the last access time of the fake file.
@@ -242,7 +245,7 @@ class FakePathModule:
             file_obj = self.filesystem.resolve(path)
         except OSError:
             self.filesystem.raise_os_error(errno.ENOENT)
-        return file_obj.st_atime
+        return file_obj.st_atime  # pytype: disable=name-error
 
     def getctime(self, path: AnyStr) -> float:
         """Returns the creation time of the fake file.
@@ -261,7 +264,7 @@ class FakePathModule:
             file_obj = self.filesystem.resolve(path)
         except OSError:
             self.filesystem.raise_os_error(errno.ENOENT)
-        return file_obj.st_ctime
+        return file_obj.st_ctime  # pytype: disable=name-error
 
     def abspath(self, path: AnyStr) -> AnyStr:
         """Return the absolute version of a path."""
@@ -351,8 +354,8 @@ class FakePathModule:
         """Return whether path1 and path2 point to the same file.
 
         Args:
-            path1: first file path or path object (Python >=3.6)
-            path2: second file path or path object (Python >=3.6)
+            path1: first file path or path object
+            path2: second file path or path object
 
         Raises:
             OSError: if one of the paths does not point to an existing
@@ -505,6 +508,14 @@ if sys.platform == "win32":
             self.filesystem = filesystem
             self.nt_module: Any = nt
 
+        def getcwd(self) -> str:
+            """Return current working directory."""
+            return to_string(self.filesystem.cwd)
+
+        def getcwdb(self) -> bytes:
+            """Return current working directory as bytes."""
+            return to_bytes(self.filesystem.cwd)
+
         if sys.version_info >= (3, 12):
 
             def _path_isdir(self, path: AnyStr) -> bool:
