@@ -27,6 +27,7 @@ import sys
 import unittest
 from collections import namedtuple
 from unittest import mock
+from unittest.mock import patch
 
 from pyfakefs import fake_pathlib, fake_filesystem, fake_filesystem_unittest, fake_os
 from pyfakefs.fake_filesystem import OSType
@@ -461,23 +462,35 @@ class FakePathlibFileObjectPropertyTest(RealPathlibTestCase):
             self.path.cwd(), self.path(self.os.path.realpath(dir_path))
         )
 
-    def test_expanduser(self):
-        if is_windows:
-            self.assertEqual(
-                self.path("~").expanduser(),
-                self.path(os.environ["USERPROFILE"].replace("\\", "/")),
-            )
-        else:
-            self.assertEqual(self.path("~").expanduser(), self.path(os.environ["HOME"]))
+    @unittest.skipIf(
+        sys.platform != "win32" or sys.version_info < (3, 8), "Windows specific test"
+    )
+    @patch.dict(os.environ, {"USERPROFILE": r"C:\Users\John"})
+    def test_expanduser_windows(self):
+        self.assertEqual(
+            self.path("~").expanduser(),
+            self.path("C:/Users/John"),
+        )
 
-    def test_home(self):
-        if is_windows:
-            self.assertEqual(
-                self.path(os.environ["USERPROFILE"].replace("\\", "/")),
-                self.path.home(),
-            )
-        else:
-            self.assertEqual(self.path(os.environ["HOME"]), self.path.home())
+    @unittest.skipIf(sys.platform == "win32", "Posix specific test")
+    @patch.dict(os.environ, {"HOME": "/home/john"})
+    def test_expanduser_posix(self):
+        self.assertEqual(self.path("~").expanduser(), self.path("/home/john"))
+
+    @unittest.skipIf(
+        sys.platform != "win32" or sys.version_info < (3, 8), "Windows specific test"
+    )
+    @patch.dict(os.environ, {"USERPROFILE": r"C:\Users\John"})
+    def test_home_windows(self):
+        self.assertEqual(
+            self.path(self.path("C:/Users/John")),
+            self.path.home(),
+        )
+
+    @unittest.skipIf(sys.platform == "win32", "Posix specific test")
+    @patch.dict(os.environ, {"HOME": "/home/john"})
+    def test_home_posix(self):
+        self.assertEqual(self.path("/home/john"), self.path.home())
 
 
 class RealPathlibFileObjectPropertyTest(FakePathlibFileObjectPropertyTest):
@@ -693,6 +706,18 @@ class FakePathlibPathFileOperationTest(RealPathlibTestCase):
             errno.EEXIST, self.path(file_name).mkdir, exist_ok=True
         )
 
+    @unittest.skipIf(not is_windows, "Windows specific behavior")
+    def test_mkdir_with_automount_unc_path(self):
+        self.skip_real_fs()
+        self.path(r"\\test\unc\foo").mkdir(parents=True)
+        self.assertTrue(self.path(r"\\test\unc\foo").exists())
+
+    @unittest.skipIf(not is_windows, "Windows specific behavior")
+    def test_mkdir_with_automount_drive(self):
+        self.skip_real_fs()
+        self.path(r"d:\foo\bar").mkdir(parents=True)
+        self.assertTrue(self.path(r"d:\foo\bar").exists())
+
     def test_rmdir(self):
         dir_name = self.make_path("foo", "bar")
         self.create_dir(dir_name)
@@ -763,8 +788,8 @@ class RealPathlibPathFileOperationTest(FakePathlibPathFileOperationTest):
 
 
 class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
-    """Test that many os / os.path functions accept a path-like object
-    since Python 3.6. The functionality of these functions is tested
+    """Test that many `os` / `os.path` functions accept a path-like object.
+    The functionality of these functions is tested
     elsewhere, we just check that they accept a fake path object as an
     argument.
     """
